searchData={"content_type":"text/markdown","items":[{"doc":"HTMeX simplifies working with the [HTMX](https://htmx.org/) javascript library in a Phoenix web application.\nHTMX can be used to improve the interactivity of you web application without\nhaving to write much javascript. It can give your site a single page application\nfeel while not requiring websockets. It achieves this by using AJAX request to\nthe backend and stitches the server response HTML into the DOM.\n\nWhy use this instead of Liveview or dead views? It is the middle ground. It\nprogressively enhances the experience of dead views, while not requiring a websocket\nconnection. If you users have network connectivity issues, it may provide a smoother\nexperience.\n\nHTMeX assists by detecting a HTMX ajax request and removing the root layout,\nso only a fragment of HTML is returned by your application, rather than the whole\npage.\n\nIn this way, if the user of your application has javascript disabled on their device,\nthey will see your basic application, and each action will cause a full HTML page to be\nsent. If they have javascript enabled, HTMeX will detect it and only send back\nthe relevant HTML snippet to be stitched into the DOM in the clients browser.","ref":"HTMeX.html","title":"HTMeX","type":"module"},{"doc":"1. Add HTMeX to `mix.exs`:\n\n```elixir\n  defmodule MyApp.MixProject do\n    # ...\n\n    defp deps do\n      [\n        # ...\n        {:htmex, \"~> 0.1.0\"}\n      ]\n    end\n  end\n  ```\n\n2. Pull down HTMeX:\n\n```\nmix deps.get\n```\n\n3. Add HTMX to your root layout (or download it and serve it as an asset) and add the `hx-boost` attribute to the body tag `my_app/lib/my_app_list_web/components/layouts/root.html.heex`:\n\n```html\n \n \n   \n  # ...\n     \n  # ...\n   \n   \n  # ...\n```\n4. Add the `:htmex` plug to your browser pipeline in `router.ex`:\n\n  ```elixir\n  defmodule MyAppWeb.Router do\n    use MyAppWeb, :router\n\n    import HTMeX\n\n    pipeline :browser do\n      # ...\n      plug :htmex\n    end\n    # ...\n```","ref":"HTMeX.html#module-getting-started","title":"Getting started - HTMeX","type":"module"},{"doc":"Check if the request has the `hx-request` header. If so, remove the root\nlayout. If the request has been `hx-boosted` return the html snippet within the page\nlayout. If the request has not been `hx-boosted` remove the page layout as well.","ref":"HTMeX.html#htmex/2","title":"HTMeX.htmex/2","type":"function"}]}